# Utilitarios Ingestão EDAT
Classes utilitarias utilizadas pelo EDAT.


# Deploy
Necessário alterar a versão do projeto no arquivo [setup.py](./setup.py).

Conferir no CI/CD se o pacote foi publicado corretamente.

